#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.0.3
id: yesod-static-1.5.0.3-bad483d80e79ed7660a6a597a8fba4ed
key: yesod_C29WbifCCpU5I6nEUHuIbj
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Static Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Generators
    Yesod.EmbeddedStatic.Types Yesod.EmbeddedStatic.Css.AbsoluteUrl
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
hs-libraries: HSyesod-static-1.5.0.3-C29WbifCCpU5I6nEUHuIbj
depends:
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
    cryptohash-conduit-0.1.1-05dcab06357a80c7bc7ae6cbc9d0516f
    css-text-0.1.2.1-5f08c8634ff151127fcfba990f98863f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    hjsmin-0.2.0.1-9b584074a533f56bfeee2bd0e05cbecb
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    mime-types-0.1.0.6-7d5f22022675c00ea07fd0f1df020c2e
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
    wai-app-static-3.1.5-3b989702052826a001c0c96e312e032f
    yesod-core-1.4.20.1-8dce2c1559c72b98aae15f98b85f32e0
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
